@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: common.py 3532 2006-08-26 22:44:28Z djpham $
+### $Id: common.py 3795 2006-12-23 10:43:23Z rogerb $
 
 
 # Documentation
@@ -281,16 +281,12 @@ def formatexception(excinfo=None, lastframes=8):
      traceback.print_exception(*excinfo, **{'file': s})
      tb=excinfo[2]
 
-     while True:
-          if not tb.tb_next:
-               break
-          tb=tb.tb_next
      stack=[]
-     f=tb.tb_frame
-     while f:
-          stack.append(f)
-          f=f.f_back
-     stack.reverse()
+
+     while tb:
+          stack.append(tb.tb_frame)
+          tb=tb.tb_next
+          
      if len(stack)>lastframes:
           stack=stack[-lastframes:]
      print >>s, "\nVariables by last %d frames, innermost last" % (lastframes,)
