@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: database.py 2939 2006-03-18 04:39:42Z rogerb $
+### $Id: database.py 3729 2006-12-05 22:16:52Z djpham $
 
 """Interface to the database"""
 
@@ -500,7 +500,7 @@ class Database:
         for k in dict.keys():
             record=dict[k]
             record["__uid__"]=k
-            rk=record.keys()
+            rk=[x for x,y in record.items() if y is not None]
             rk.sort()
             cmd=["insert into", idquote(tablename), "( [__timestamp__],"]
             cmd.append(",".join([idquote(r) for r in rk]))
