@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: gui.py 3628 2006-10-25 20:11:31Z djpham $
+### $Id: gui.py 3793 2006-12-22 04:00:51Z djpham $
 
 """The main gui code for BitPim"""
 
@@ -54,6 +54,7 @@ import playlist
 import fileview
 import data_recording
 import analyser
+import t9editor
 
 if guihelper.IsMSWindows():
     import win32api
@@ -332,7 +333,12 @@ class Config(ConfigParser.ConfigParser):
         if guihelper.IsMSWindows(): # we want subdir of my documents on windows
             # nice and painful
             from win32com.shell import shell, shellcon
-            path=shell.SHGetFolderPath(0, shellcon.CSIDL_PERSONAL, None, 0)
+            try:
+                path=shell.SHGetFolderPath(0, shellcon.CSIDL_PERSONAL, None, 0)
+            except: # it will fail if path doesn't exist.  one example was a user
+                # putting my docs on an external usb drive that isn't plugged in
+                # when starting bitpim
+                path=r"c:\My BitPim Files"
             path=os.path.join(path, "bitpim")
         else:
             path=os.path.expanduser("~/.bitpim-files")
@@ -1018,6 +1024,9 @@ class MainWindow(wx.Frame):
     def GetActiveSMSWidget(self):
         return self.tree.GetActivePhone().smswidget
 
+    def GetActiveT9EditorWidget(self):
+        return self.tree.GetActivePhone().t9editorwidget
+
     def GetCurrentActiveWidget(self):
         return self.tree.GetActiveWidget()
 
@@ -1450,6 +1459,12 @@ class MainWindow(wx.Frame):
                 raise NotImplementedError
             self.GetActivePlaylistWidget().populatefs(results)
             self.GetActivePlaylistWidget().populate(results)
+        # T9 User DB
+        if results['sync'].has_key(t9editor.dict_key):
+            if results['sync'][t9editor.dict_key]=='MERGE':
+                raise NotImplementedError
+            self.GetActiveT9EditorWidget().populatefs(results)
+            self.GetActiveT9EditorWidget().populate(results)
     ###
     ### Main bit for sending data to the phone
     ###
@@ -1537,6 +1552,13 @@ class MainWindow(wx.Frame):
             self.GetActivePlaylistWidget().getdata(data)
             todo.append((self.wt.writeplaylist, "Playlist", merge))
 
+        ### T9 User DB
+        v=dlg.GetT9Setting()
+        if v!=dlg.NOTREQUESTED:
+            merge=v!=dlg.OVERWRITE
+            self.GetActiveT9EditorWidget().getdata(data)
+            todo.append((self.wt.writet9, "T9", merge))
+
         data['reboot_delay']=self.phoneprofile.reboot_delay
         self._autodetect_delay=self.phoneprofile.autodetect_delay
         todo.append((self.wt.rebootcheck, "Phone Reboot"))
@@ -1878,7 +1900,9 @@ class WorkerThread(WorkerThreadFramework):
             (req.GetTodoSetting, self.commphone.gettodo, "Todo", "todo"),
             (req.GetSMSSetting, self.commphone.getsms, "SMS", "sms"),
             (req.GetCallHistorySetting, self.commphone.getcallhistory, 'Call History', 'call_history'),
-            (req.GetPlaylistSetting, self.commphone.getplaylist, 'Play List', 'playlist')):
+            (req.GetPlaylistSetting, self.commphone.getplaylist, 'Play List', 'playlist'),
+            (req.GetT9Setting, self.commphone.gett9db, 'T9 DB', t9editor.dict_key),
+            ):
             st=i[0]()
             if st==req.MERGE:
                 sync[i[3]]="MERGE"
@@ -1967,6 +1991,12 @@ class WorkerThread(WorkerThreadFramework):
         self.setupcomm()
         return self.commphone.saveplaylist(data, merge)
 
+    def writet9(self, data, merge):
+        if __debug__:
+            self.checkthread()
+        self.setupcomm()
+        return self.commphone.savet9db(data, merge)
+
     def getphoneinfo(self):
         if __debug__: self.checkthread()
         self.setupcomm()
