@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: guiwidgets.py 3529 2006-08-21 23:31:16Z djpham $
+### $Id: guiwidgets.py 3793 2006-12-22 04:00:51Z djpham $
 
 """Most of the graphical user interface elements making up BitPim"""
 
@@ -33,6 +33,7 @@ import wx.lib.intctrl
 import wx.lib.newevent
 import wx.lib.mixins.listctrl  as  listmix
 import wx.lib.stattext as stattext
+from wx.lib.masked import NumCtrl
 
 # my modules
 import common
@@ -169,7 +170,8 @@ class GetPhoneDialog(wx.Dialog):
                ('Todo', 'todo'),
                ('SMS', 'sms'),
                ('Call History', 'call_history'),
-               ('Play List', 'playlist'))
+               ('Play List', 'playlist'),
+               ('T9 User DB','t9_udb'))
     
     # actions ("Pretty Name", "name used to query profile")
     actions = (  ("Get", "read"), )
@@ -266,6 +268,8 @@ class GetPhoneDialog(wx.Dialog):
         return self._setting("call_history")
     def GetPlaylistSetting(self):
         return self._setting('playlist')
+    def GetT9Setting(self):
+        return self._setting('t9_udb')
 
     def OnHelp(self,_):
         wx.GetApp().displayhelpid(self.HELPID)
@@ -278,7 +282,8 @@ class GetPhoneDialog(wx.Dialog):
         ('ringtone', 'read', MERGE),
         ('memo', 'read', MERGE),
         ('todo', 'read', MERGE),
-        ('playlist', 'read', MERGE))
+        ('playlist', 'read', MERGE),
+        ('t9_udb', 'read', MERGE))
 
     def _dowesupport(self, source, action, type):
         if (source,action,type) in self._notsupported:
@@ -451,7 +456,15 @@ class ConfigDialog(wx.Dialog):
                                      'Detect phone at bitpim startup')
         gs.Add(self.autodetect_start, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
         _row+=1
-
+        # Splashscreen time
+        gs.Add(wx.StaticText(self, -1, 'SplashScreen Time (sec)'),
+               pos=(_row, 0),
+               flag=wx.ALIGN_CENTER_VERTICAL)
+        self.splashscreen=NumCtrl(self, -1,
+                                  integerWidth=2, fractionWidth=1,
+                                  allowNegative=False)
+        gs.Add(self.splashscreen, pos=(_row, 1), flag=wx.ALIGN_CENTER_VERTICAL)
+        _row+=1
         # bitfling
         if bitflingscan.IsBitFlingEnabled():
             self.SetupBitFlingCertVerification()
@@ -633,6 +646,7 @@ class ConfigDialog(wx.Dialog):
                 self.taskbaricon1.SetValue(False)
                 self.taskbaricon1.Enable(False)
         self.autodetect_start.SetValue(self.mw.config.ReadInt("autodetectstart", 0))
+        self.splashscreen.SetValue(self.mw.config.ReadInt('splashscreentime', 2500)/1000.0)
 
     def setdefaults(self):
         if self.commbox.GetValue()==self.setme:
@@ -687,6 +701,9 @@ class ConfigDialog(wx.Dialog):
             self.mw.config.WriteInt('taskbaricon1', 0)
         # startup autodetect option
         self.mw.config.WriteInt('autodetectstart', self.autodetect_start.GetValue())
+        # SplashScreen Time
+        self.mw.config.WriteInt('splashscreentime',
+                                int(self.splashscreen.GetValue()*1000))
         # ensure config is saved
         self.mw.config.Flush()
         # update the status bar
