@@ -7,7 +7,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: package.py 3594 2006-10-03 02:44:50Z djpham $
+### $Id: package.py 3771 2006-12-11 04:44:56Z djpham $
 
 # This file provides the packaging definitions used by the buildrelease system
 
@@ -23,6 +23,11 @@ def sanitycheck():
     
     print "=== Sanity check ==="
 
+    print "svn location",
+    if not "$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/0.9.10/src/package.py $".split(":",1)[1].strip().startswith("https://bitpim.svn.sourceforge.net"):
+        raise Exception("Needs to be checked out from https://bitpim.svn.sourceforge.net")
+    print "  OK"
+
     print "python version",
     if sys.version_info[:2]!=(2,3):
        raise Exception("Should be  Python 2.3 - this is "+sys.version)
@@ -227,14 +232,17 @@ def copyresources(destdir):
 
 def resourcefilter(srcfilename, destfilename):
     exts=[ '.xy', '.png', '.ttf', '.wav', '.jpg', '.css', '.pdc', '.ids', '.ico']
+    files=[]
     if sys.platform=='win32':
         # on windows we also want the chm help file 
         exts=exts+['.chm', '.exe', '.dll']
     if sys.platform=='linux2':
         exts=exts+['.lbin', '.htb']
+        files.append('usbcell')
     if sys.platform=='darwin':
         exts=exts+['.mbin', '.htb']
-    if os.path.splitext(srcfilename)[1] in exts:
+    if os.path.splitext(srcfilename)[1] in exts or \
+       os.path.basename(srcfilename) in files:
         return srcfilename, destfilename
     return None
 
@@ -303,7 +311,7 @@ def getvals():
         'DQVERSION': version.dqverstr,
         'COMMENTS': "Provided under the GNU Public License (GPL)",
         'DESCRIPTION': "View and manipulate data on many CDMA phones from LG, Samsung, Sanyo and other manufacturers. This includes the PhoneBook, Calendar, WallPapers, RingTones (functionality varies by phone) and the Filesystem for most Qualcomm CDMA chipset based phones.",
-        'COPYRIGHT': "Copyright  2003-2006 The BitPim developers",
+        'COPYRIGHT': "Copyright (C) 2003-2006 The BitPim developers",
         'URL': version.url,
         'SUPPORTURL': "http://www.bitpim.org/help/support.htm",
         'GUID': "{FA61D601-A0FC-48BD-AE7A-54946BCD7FB6}",
