@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: phonebookentryeditor.py 3323 2006-06-01 04:27:31Z djpham $
+### $Id: phonebookentryeditor.py 3647 2006-11-08 03:39:16Z djpham $
 
 import wx
 
@@ -580,6 +580,20 @@ class MemoEditor(DirtyUIBase):
             return {'memo': self.memo.GetValue()}
         return {}
 
+    # copy/cut/paste routines
+    def CanCopy(self):
+        return self.memo.CanCopy()
+    def Copy(self):
+        return self.memo.Copy()
+    def CanPaste(self):
+        return self.memo.CanPaste()
+    def Paste(self):
+        return self.memo.Paste()
+    def CanCut(self):
+        return self.memo.CanCut()
+    def Cut(self):
+        return self.memo.Cut()
+
 # NumberEditor------------------------------------------------------------------
 class NumberEditor(DirtyUIBase):
 
