@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: __init__.py 3596 2006-10-03 03:06:14Z sawecw $
+### $Id: __init__.py 3788 2006-12-20 23:15:29Z djpham $
 
 
 # phone carriers
@@ -106,10 +106,18 @@ _phonedata= { 'LG-G4015': { 'module': 'com_lgg4015',
                              'carrier': [c_vzw],
                              'brand': b_lg,
                              },
+              'LG-VX8600': { 'module': 'com_lgvx8600',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             },
               'LG-VX9800': { 'module': 'com_lgvx9800',
                              'carrier': [c_vzw],
                              'brand': b_lg,
                              },
+              'LG-VX9900': { 'module': 'com_lgvx9900',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             },
               'LG-VI125': { 'module': 'com_lgvi125',
                             'carrier': [c_sprint],
                             'brand': b_lg,
@@ -160,6 +168,10 @@ _phonedata= { 'LG-G4015': { 'module': 'com_lgg4015',
                            'carrier': [c_sprint],
                            'brand': b_sanyo,
                            },
+              'SCP-200': { 'module': 'com_sanyo200',
+                            'carrier': [c_sprint],
+                            'brand': b_sanyo,
+                            },
               'SCP-3100': { 'module': 'com_sanyo3100',
                             'carrier': [c_sprint],
                             'brand': b_sanyo,
