@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_brew.py 3593 2006-10-03 02:44:11Z djpham $
+### $Id: com_brew.py 3725 2006-12-05 03:50:54Z djpham $
 
 """Implements the "Brew" filesystem protocol"""
 
@@ -501,7 +501,11 @@ class RealBrewProtocol:
                 return {}
         if _broken_date:
             for _key,_entry in results.items():
-                _entry['date']=self.statfile(_key)['date']
+                _stat=self.statfile(_key)
+                if _stat:
+                    _entry['date']=_stat.get('date', (0, ''))
+                else:
+                    _entry['date']=(0, '')
         return results
 
     def getfilesystem(self, dir="", recurse=0):
