@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx4400.py 3204 2006-05-06 05:22:21Z djpham $
+### $Id: com_lgvx4400.py 3630 2006-10-25 21:07:20Z djpham $
 
 """Communicate with the LG VX4400 cell phone"""
 
@@ -311,8 +311,9 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
                     if call.name:
                         entry.name=call.name
                 res[entry.id]=entry
-        except com_brew.BrewNoSuchFileException:
-            pass # do nothing if file doesn't exist
+        except (com_brew.BrewNoSuchFileException,
+                IndexError):
+            pass # do nothing if file doesn't exist or is corrupted
         return
 
     def getwallpaperindices(self, results):
@@ -366,21 +367,27 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
         problemsdetected=False
         dupecheck={}
         for i in loop:
-            if hardway:
-                numentries+=1
-            req=self.protocolclass.pbreadentryrequest()
-            res=self.sendpbcommand(req, self.protocolclass.pbreadentryresponse)
-            self.log("Read entry "+`i`+" - "+res.entry.name)
-            entry=self.extractphonebookentry(res.entry, speeds, result)
-            if hardway and firstserial is None:
-                firstserial=res.entry.serial1
-            pbook[i]=entry
-            if res.entry.serial1 in dupecheck:
-                self.log("Entry %s has same serial as entry %s.  This will cause problems." % (`entry`, dupecheck[res.entry.serial1]))
-                problemsdetected=True
-            else:
-                dupecheck[res.entry.serial1]=entry
-            self.progress(i, numentries, res.entry.name)
+            try:
+                if hardway:
+                    numentries+=1
+                req=self.protocolclass.pbreadentryrequest()
+                res=self.sendpbcommand(req, self.protocolclass.pbreadentryresponse)
+                self.log("Read entry "+`i`+" - "+res.entry.name)
+                entry=self.extractphonebookentry(res.entry, speeds, result)
+                if hardway and firstserial is None:
+                    firstserial=res.entry.serial1
+                pbook[i]=entry
+                if res.entry.serial1 in dupecheck:
+                    self.log("Entry %s has same serial as entry %s.  This will cause problems." % (`entry`, dupecheck[res.entry.serial1]))
+                    problemsdetected=True
+                else:
+                    dupecheck[res.entry.serial1]=entry
+                self.progress(i, numentries, res.entry.name)
+            except:
+                # Something's wrong with this entry, log it and skip
+                self.log('Failed to read entry %d'%i)
+                if __debug__:
+                    raise
             #### Advance to next entry
             req=self.protocolclass.pbnextentryrequest()
             res=self.sendpbcommand(req, self.protocolclass.pbnextentryresponse)
@@ -824,7 +831,8 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
                 s=self.getfilecontents(self.brew_version_file)
                 res[self.brew_version_txt_key]=s
             except (com_brew.BrewNoSuchFileException,
-                    com_brew.BrewBadBrewCommandException):
+                    com_brew.BrewBadBrewCommandException,
+                    com_brew.BrewAccessDeniedException):
                 res[self.brew_version_txt_key]=None
             except:
                 if __debug__:
@@ -1001,7 +1009,14 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
         # do exceptions
         cal_ex=exceptions.get(event.pos, [])
         for e in cal_ex:
-            rep.add_suppressed(*e)
+            try:
+                rep.add_suppressed(*e)
+            except ValueError:
+                # illegal exception date
+                pass
+            except:
+                if __debug__:
+                    raise
         return rep
 
     def _get_voice_id(self, event, entry):
@@ -1009,35 +1024,43 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
             entry.voice=event.voiceid
 
     def _build_cal_entry(self, event, exceptions, ringtone_index):
-        # return a copy of bpcalendar object based on my values
-        # general fields
-        entry=bpcalendar.CalendarEntry()
-        entry.start=event.start
         try:
-            entry.end=event.end
-        # some phones (e.g. lx5550) have unreliable end dates for "forever" events
+            # return a copy of bpcalendar object based on my values
+            # general fields
+            entry=bpcalendar.CalendarEntry()
+            entry.start=event.start
+            try:
+                entry.end=event.end
+            # some phones (e.g. lx5550) have unreliable end dates for "forever" events
+            except ValueError:
+                entry.end=self.protocolclass.CAL_REPEAT_DATE
+            entry.desc_loc=event.description
+            # check for allday event
+            if entry.start[3:]==(0, 0) and entry.end[3:]==(23, 59):
+                entry.allday=True
+            # alarm
+            if event.alarmtype:
+                entry.alarm=event.alarmhours*60+event.alarmminutes
+            # ringtone
+            rt_idx=event.ringtone
+            # hack to account for the VX4650 weird ringtone setup
+            if rt_idx<50:
+                # 1st part of builtin ringtones, need offset by 1
+                rt_idx+=1
+            entry.ringtone=ringtone_index.get(rt_idx, {'name': None} )['name']
+            # voice ID if applicable
+            if self._cal_has_voice_id:
+                self._get_voice_id(event, entry)
+            # repeat info
+            entry.repeat=self._build_cal_repeat(event, exceptions)
+            return entry
         except ValueError:
-            entry.end=self.protocolclass.CAL_REPEAT_DATE
-        entry.desc_loc=event.description
-        # check for allday event
-        if entry.start[3:]==(0, 0) and entry.end[3:]==(23, 59):
-            entry.allday=True
-        # alarm
-        if event.alarmtype:
-            entry.alarm=event.alarmhours*60+event.alarmminutes
-        # ringtone
-        rt_idx=event.ringtone
-        # hack to account for the VX4650 weird ringtone setup
-        if rt_idx<50:
-            # 1st part of builtin ringtones, need offset by 1
-            rt_idx+=1
-        entry.ringtone=ringtone_index.get(rt_idx, {'name': None} )['name']
-        # voice ID if applicable
-        if self._cal_has_voice_id:
-            self._get_voice_id(event, entry)
-        # repeat info
-        entry.repeat=self._build_cal_repeat(event, exceptions)
-        return entry
+            # illegal date/time
+            pass
+        except:
+            # this entry is hosed!
+            if __debug__:
+                raise
 
     def get_cal(self, sch_file, exceptions, ringtone_index):
         res={}
@@ -1045,7 +1068,8 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
             if event.pos==-1:   # blank entry
                 continue
             cal_event=self._build_cal_entry(event, exceptions, ringtone_index)
-            res[cal_event.id]=cal_event
+            if cal_event:
+                res[cal_event.id]=cal_event
         return res
 
     _alarm_info={
@@ -1285,7 +1309,7 @@ class Profile(parentprofile):
                     name=data['groups'][k]['name']
                     pad.append(name)
 
-        groups=helper.getmostpopularcategories(10, data['phonebook'], ["No Group"], 22, pad)
+        groups=helper.getmostpopularcategories(self.protocolclass.MAX_PHONEBOOK_GROUPS, data['phonebook'], ["No Group"], 22, pad)
 
         # alpha sort
         groups.sort()
@@ -1395,8 +1419,8 @@ class Profile(parentprofile):
                             break
                     if len(e['numbertypes'])==b4:
                         # we couldn't find a type for the number
-                        helper.add_error_message("%s has number %s of type %s, the phone does not support this type" % 
-                                                (e['name'], num['number'], num['type']))
+                        helper.add_error_message('Number %s (%s/%s) not supported and ignored.'%
+                                                 (num['number'], e['name'], num['type']))
                         continue 
                     # deal with number
                     number=self.phonize(num['number'])
