@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: $
+### $Id: com_moto.py 3641 2006-11-08 02:43:05Z sawecw $
 
 """Communicate with Motorola phones using AT commands"""
 
@@ -343,7 +343,7 @@ class Phone(com_gsm.Phone, com_brew.BrewProtocol):
             _req.end_index=_end_idx
             for _retry_cnt in range(2):
                 try:
-                    self.progress(_total_entries, _end_idx,
+                    self.progress(_end_idx, _total_entries,
                                   'Reading conatct entry %d to %d'%(_start_idx, _end_idx))
                     _res=self.sendATcommand(_req, self.protocolclass.read_pb_resp)
                     for _entry in _res:
@@ -415,7 +415,7 @@ class Phone(com_gsm.Phone, com_brew.BrewProtocol):
             _req.end_index=_end_idx
             for _retry in range(2):
                 try:
-                    self.progress(_total_entries, _end_idx,
+                    self.progress(_end_idx, _total_entries,
                                   'Reading calendar entry %d to %d'%(_start_idx, _end_idx))
                     _res=self.sendATcommand(_req, self.protocolclass.calendar_req_resp)
                     for _entry in _res:
@@ -554,7 +554,8 @@ class Phone(com_gsm.Phone, com_brew.BrewProtocol):
                 _sms_item.readfrombuffer(_buf,
                                          logtitle='Reading an SMS List Item')
                 try:
-                    _res=self.comm.sendatcommand('+MMGR=%d'%_sms_item.index)
+                    _res=self.comm.sendatcommand('+MMGR=%d'%_sms_item.index,
+                                                 retry=True)
                     self._process_sms_result(_res, _sms, fundamentals)
                 except commport.ATError:
                     pass
