@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_sanyo.py 3525 2006-08-20 05:39:24Z sawecw $
+### $Id: com_sanyo.py 3720 2006-12-03 03:38:31Z sawecw $
 
 """Phonebook conversations with Sanyo phones"""
 
@@ -50,6 +50,8 @@ class SanyoPhonebook:
 
     calendar_defaultringtone=0
     calendar_defaultcaringtone=0
+    calendar_voicenumber=0
+    phonebook_voicenumber=0
 
     def __init__(self):
         self.numbertypetab=numbertypetab
@@ -324,28 +326,39 @@ class SanyoPhonebook:
         gsms = {}
         self.log("Getting sms entries")
         req=self.protocolclass.messagerequest()
-        for slot in range(self.protocolclass.NUMMESSAGESLOTS):
-            req.slot=slot
-            res=self.sendpbcommand(req, self.protocolclass.messageresponse)
-            if res.entry.dunno4==2:
-                entry=sms.SMSEntry()
-                entry.folder=entry.Folder_Inbox
-                entry.datetime="200%d%02d%02dT%02d%02d%02d" % ((res.entry.year, res.entry.month, res.entry.day, res.entry.hour,res.entry.minute, res.entry.second))
-                if res.entry.read==17:
-                    entry.read=1
-                else:
-                    entry.read=0
-                entry._from=res.entry.phonenum
-                entry.callback=res.entry.callback
-                entry.subject="%d-%s-%s" % ((res.entry.counter, res.entry.phonenum, res.entry.message[:12]))
-                self.log(res.entry.message[:8])
-                if res.entry.priority==100:
-                    entry.priority=sms.SMSEntry.Priority_Normal
-                if res.entry.priority==200:
-                    entry.priority=sms.SMSEntry.Priority_High
-                entry.text=res.entry.message
-                gsms[entry.id]=entry
-                result['sms']=gsms
+        for box in range(2):
+            if box==0:
+                req=self.protocolclass.messagerequest()
+                respc=self.protocolclass.messageresponse
+            else:
+                req=self.protocolclass.messagesentrequest()
+                respc=self.protocolclass.messagesentresponse
+            for slot in range(self.protocolclass.NUMMESSAGESLOTS):
+                req.slot=slot
+                res=self.sendpbcommand(req, respc)
+                if res.entry.dunno4==2:
+                    entry=sms.SMSEntry()
+                    if box==0:
+                        entry.folder=entry.Folder_Inbox
+                        entry._from=res.entry.phonenum
+                    else:
+                        entry.folder=entry.Folder_Sent
+                        entry._to=res.entry.phonenum
+                    entry.datetime="200%d%02d%02dT%02d%02d%02d" % ((res.entry.year, res.entry.month, res.entry.day, res.entry.hour,res.entry.minute, res.entry.second))
+                    if res.entry.read==17:
+                        entry.read=1
+                    else:
+                        entry.read=0
+                    entry.callback=res.entry.callback
+                    entry.subject=res.entry.message[:12]
+                    self.log(res.entry.message[:8])
+                    if res.entry.priority==100:
+                        entry.priority=sms.SMSEntry.Priority_Normal
+                    if res.entry.priority==200:
+                        entry.priority=sms.SMSEntry.Priority_High
+                    entry.text=res.entry.message
+                    gsms[entry.id]=entry
+                    result['sms']=gsms
         return result
 
     def gettodo(self, result):
@@ -419,6 +432,7 @@ class SanyoPhonebook:
                 if self.protocolclass.HASRINGPICBUF:
                     # ringtones
                     if ringpic.ringtones[i].ringtone>0:
+                        print res.entry.name,ringpic.ringtones[i].ringtone
                         try:
                             tone=result['ringtone-index'][ringpic.ringtones[i].ringtone]['name']
                         except:
@@ -973,8 +987,13 @@ class SanyoPhonebook:
                 alarmtime=res.entry.alarm
                 entry.alarm=(starttime-alarmtime)/60
             ringtone=res.entry.ringtone
+            print "ringtone=",ringtone
+            if self.calendar_voicenumber and ringtone == self.calendar_voicenumber:
+                ringtone=self.phonebook_voicenumber
             if ringtone in self.calendar_tonerange:
+                print "Adjusting ringtone by",-self.calendar_toneoffset
                 ringtone-=self.calendar_toneoffset
+                print "ringtone=",ringtone
             if ringtone!=self.calendar_defaultringtone:
                 if result['ringtone-index'].has_key(ringtone):
                     entry.ringtone=result['ringtone-index'][ringtone]['name']
@@ -1119,14 +1138,6 @@ class SanyoPhonebook:
                 e=self.protocolclass.evententry()
                 e.slot=eventslot
 
-                slashpos=descloc.find('/')
-                if(slashpos >= 0):
-                    eventname=descloc[0:slashpos]
-                    location=descloc[slashpos+1:]
-                else:
-                    eventname=descloc
-                    location=''
-            
                 e.eventname=descloc
                 e.eventname_len=len(e.eventname)
                 e.location=entry.location
@@ -1179,6 +1190,8 @@ class SanyoPhonebook:
                     e.ringtone=ringtoneindex
                     if e.ringtone in save_tonerange:
                         e.ringtone+=self.calendar_toneoffset
+                    if self.calendar_voicenumber and e.ringtone==self.phonebook_voicenumber:
+                        e.ringtone=self.calendar_voicenumber
                 # Use default ringtone for now
                 #e.ringtone=self.calendar_defaultringtone
                 print "Setting ringtone "+`e.ringtone`
