@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: vcard.py 2564 2005-10-19 02:31:38Z skyjunky $
+### $Id: vcard.py 3619 2006-10-20 03:50:15Z djpham $
 
 """Code for reading and writing Vcard
 
@@ -273,7 +273,7 @@ class VCard:
     _field_REV=_field_ignore          # not stored in bitpim
     _field_KEY=_field_ignore          # not stored in bitpim
     _field_SOURCE=_field_ignore       # not stored in bitpim (although arguably part of serials)
-
+    _field_PHOTO=_field_ignore        # contained either binary image, or external URL, not used by BitPim
 
     # simple fields
     
@@ -523,13 +523,6 @@ class VCard:
         else:
             result['categories']=';'.join(values)
 
-    def _field_PHOTO(self, field, value, result):
-        # comma seperated just for fun
-        values=self.splitandunquote(value, seperator=",")
-        values=[v.replace(";", "").strip() for v in values]  # semi colon is used as seperator in bitpim text field
-        values=[v for v in values if len(v)]
-        result[self._getfieldname("wallpapers", result)]=";".join(values)
-        
     def _field_SOUND(self, field, value, result):
         # comma seperated just for fun
         values=self.splitandunquote(value, seperator=",")
@@ -868,17 +861,39 @@ def out_adr(vals, formatter):
 def out_note(vals, formatter, limit=1):
     return "".join([out_line("NOTE", None, v["memo"], formatter) for v in vals[:limit]])
 
-def out_wallpapers(vals, formatter):
-    w=[v.get("wallpaper") for v in vals]
-    if len(w):
-        return out_line('PHOTO', None, w, formatter, join_char=",")
-    return ""
-
-def out_ringtones(vals, formatter):
-    r=[v.get("ringtone") for v in vals]
-    if len(r):
-        return out_line('SOUND', None, r, formatter, join_char=",")
-    return ""
+# Sany SCP-6600 (Katana) support
+def out_tel_scp6600(vals, formatter):
+    res=""
+    _pref=len(vals)>1
+    for v in vals:
+        res+=out_line("TEL",
+                      ["TYPE=%s%s" % (_pref and "PREF," or "",
+                                      _out_tel_mapping[v['type']])],
+                      phonenumber.format(v['number']), formatter)
+        _pref=False
+    return res
+def out_email_scp6600(vals, formatter):
+    res=''
+    for _idx in range(min(len(vals), 2)):
+        v=vals[_idx]
+        if v.get('email', None):
+            res+=out_line('EMAIL', ['TYPE=INTERNET'],
+                          v['email'], formatter)
+    return res
+def out_url_scp660(vals, formatter):
+    if vals and vals[0].get('url', None):
+        return out_line('URL', None, vals[0]['url'], formatter)
+    return ''
+def out_adr_scp6600(vals, formatter):
+    for v in vals:
+        if v.get('type', None)=='home':
+            _type='HOME'
+        else:
+            _type='WORK'
+        return out_line("ADR", ['TYPE=%s'%_type],
+                        [v.get(k, "") for k in (None, "street2", "street", "city", "state", "postalcode", "country")],
+                        formatter)
+    return ''
 
 # This is the order we write things out to the vcard.  Although
 # vCard doesn't require an ordering, it looks nicer if it
@@ -926,8 +941,6 @@ profile_vcard2={
     'numbers': out_tel,
     'addresses': out_adr,
     'memos': out_note,
-    'wallpapers': out_wallpapers,
-    'ringtones': out_ringtones
     }
 
 profile_vcard3=profile_vcard2.copy()
@@ -940,11 +953,22 @@ profile_apple['categories']=out_categories_apple
 profile_full=profile_vcard3.copy()
 profile_full['_limit']=99999
 
+profile_scp6600=profile_full.copy()
+del profile_scp6600['categories']
+profile_scp6600.update(
+    { 'numbers': out_tel_scp6600,
+      'emails': out_email_scp6600,
+      'urls': out_url_scp660,
+      'addresses': out_adr_scp6600,
+      })
+
 profiles={
     'vcard2':  { 'description': "vCard v2.1", 'profile': profile_vcard2 },
     'vcard3':  { 'description': "vCard v3.0", 'profile': profile_vcard3 },
     'apple':   { 'description': "Apple",      'profile': profile_apple  },
     'fullv3':  { 'description': "Full vCard v3.0", 'profile': profile_full},
+    'scp6600': { 'description': "Sanyo SCP-6600 (Katana)",
+                 'profile': profile_scp6600 },
 }
     
     
