@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: version.py 3484 2006-07-16 02:56:36Z rogerb $
+### $Id: version.py 3750 2006-12-07 02:55:52Z rogerb $
 
 """Information about BitPim version number"""
 
@@ -15,13 +15,13 @@
 # in the dollar id fields.  When freeze is run, it does those various
 # substitutions
 
-__FROZEN__="$Id: 3690 $"
+__FROZEN__="$Id: 3826 $"
 
 import os, sys
 import time
 
 name="BitPim"
-vendor="$Id: version.py 3484 2006-07-16 02:56:36Z rogerb $"
+vendor="$Id: version.py 3750 2006-12-07 02:55:52Z rogerb $"
 release=0  # when rereleases of the same version happen, this gets incremented
 contact="The BitPim home page is at http://www.bitpim.org.  You can post any " \
          "questions or feedback to the mailing list detailed on that page." # where users are sent to contact with feedback
@@ -39,9 +39,9 @@ if vendor[1:].startswith("Id:"):
     else:
         vendor=vendor.split()[1]
 
-_headurl="$HeadURL: https://svn.sourceforge.net/svnroot/bitpim/releases/0.9.08/src/version.py $".split()[1]
+_headurl="$HeadURL: https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/0.9.10/src/version.py $".split()[1]
 # work out our version number
-_rp="https://svn.sourceforge.net/svnroot/bitpim/releases/"
+_rp="https://bitpim.svn.sourceforge.net/svnroot/bitpim/releases/"
 if _headurl.startswith(_rp):
     def isdevelopmentversion(): return False
     version=_headurl[len(_rp):].split("/")[0]
